@@ -36,7 +36,8 @@ class EmrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateInstance", params)
+            headers = request.headers
+            body = self.call("CreateInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateInstanceResponse()
@@ -64,7 +65,8 @@ class EmrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeClusterNodes", params)
+            headers = request.headers
+            body = self.call("DescribeClusterNodes", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeClusterNodesResponse()
@@ -82,6 +84,35 @@ class EmrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeCvmQuota(self, request):
+        """获取账户的CVM配额
+
+        :param request: Request instance for DescribeCvmQuota.
+        :type request: :class:`tencentcloud.emr.v20190103.models.DescribeCvmQuotaRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.DescribeCvmQuotaResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeCvmQuota", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeCvmQuotaResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeInstanceRenewNodes(self, request):
         """预付费集群隔离后续费资源查询
 
@@ -92,7 +123,8 @@ class EmrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeInstanceRenewNodes", params)
+            headers = request.headers
+            body = self.call("DescribeInstanceRenewNodes", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeInstanceRenewNodesResponse()
@@ -120,7 +152,8 @@ class EmrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeInstances", params)
+            headers = request.headers
+            body = self.call("DescribeInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeInstancesResponse()
@@ -148,7 +181,8 @@ class EmrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeJobFlow", params)
+            headers = request.headers
+            body = self.call("DescribeJobFlow", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeJobFlowResponse()
@@ -166,6 +200,35 @@ class EmrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeResourceSchedule(self, request):
+        """获取yarn资源调度页面的数据
+
+        :param request: Request instance for DescribeResourceSchedule.
+        :type request: :class:`tencentcloud.emr.v20190103.models.DescribeResourceScheduleRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.DescribeResourceScheduleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeResourceSchedule", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeResourceScheduleResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def InquirePriceRenewEmr(self, request):
         """集群续费询价。
 
@@ -176,7 +239,8 @@ class EmrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InquirePriceRenewEmr", params)
+            headers = request.headers
+            body = self.call("InquirePriceRenewEmr", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InquirePriceRenewEmrResponse()
@@ -204,7 +268,8 @@ class EmrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InquiryPriceCreateInstance", params)
+            headers = request.headers
+            body = self.call("InquiryPriceCreateInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InquiryPriceCreateInstanceResponse()
@@ -232,7 +297,8 @@ class EmrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InquiryPriceRenewInstance", params)
+            headers = request.headers
+            body = self.call("InquiryPriceRenewInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InquiryPriceRenewInstanceResponse()
@@ -260,7 +326,8 @@ class EmrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InquiryPriceScaleOutInstance", params)
+            headers = request.headers
+            body = self.call("InquiryPriceScaleOutInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InquiryPriceScaleOutInstanceResponse()
@@ -288,7 +355,8 @@ class EmrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InquiryPriceUpdateInstance", params)
+            headers = request.headers
+            body = self.call("InquiryPriceUpdateInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InquiryPriceUpdateInstanceResponse()
@@ -306,6 +374,93 @@ class EmrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyResourcePools(self, request):
+        """刷新动态资源池
+
+        :param request: Request instance for ModifyResourcePools.
+        :type request: :class:`tencentcloud.emr.v20190103.models.ModifyResourcePoolsRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.ModifyResourcePoolsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyResourcePools", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyResourcePoolsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def ModifyResourceScheduleConfig(self, request):
+        """修改yarn资源调度的资源配置
+
+        :param request: Request instance for ModifyResourceScheduleConfig.
+        :type request: :class:`tencentcloud.emr.v20190103.models.ModifyResourceScheduleConfigRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.ModifyResourceScheduleConfigResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyResourceScheduleConfig", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyResourceScheduleConfigResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def ModifyResourceScheduler(self, request):
+        """修改了yarn的资源调度器，点击部署生效
+
+        :param request: Request instance for ModifyResourceScheduler.
+        :type request: :class:`tencentcloud.emr.v20190103.models.ModifyResourceSchedulerRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.ModifyResourceSchedulerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyResourceScheduler", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyResourceSchedulerResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def RunJobFlow(self, request):
         """创建流程作业
 
@@ -316,7 +471,8 @@ class EmrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RunJobFlow", params)
+            headers = request.headers
+            body = self.call("RunJobFlow", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RunJobFlowResponse()
@@ -344,7 +500,8 @@ class EmrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ScaleOutInstance", params)
+            headers = request.headers
+            body = self.call("ScaleOutInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ScaleOutInstanceResponse()
@@ -362,6 +519,35 @@ class EmrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def SyncPodState(self, request):
+        """EMR同步TKE中POD状态
+
+        :param request: Request instance for SyncPodState.
+        :type request: :class:`tencentcloud.emr.v20190103.models.SyncPodStateRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.SyncPodStateResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("SyncPodState", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.SyncPodStateResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def TerminateInstance(self, request):
         """销毁EMR实例。此接口仅支持弹性MapReduce正式计费版本。
 
@@ -372,7 +558,8 @@ class EmrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("TerminateInstance", params)
+            headers = request.headers
+            body = self.call("TerminateInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.TerminateInstanceResponse()
@@ -400,7 +587,8 @@ class EmrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("TerminateTasks", params)
+            headers = request.headers
+            body = self.call("TerminateTasks", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.TerminateTasksResponse()
