@@ -35,7 +35,7 @@ class ApproverInfo(AbstractModel):
 0：企业
 1：个人
 3：企业静默签署
-注：类型为3（企业静默签署）时，此接口会默认完成该签署方的签署，目前只支持第一方进行静默签署。
+注：类型为3（企业静默签署）时，此接口会默认完成该签署方的签署。
         :type ApproverType: int
         :param ApproverName: 本环节需要操作人的名字
         :type ApproverName: str
@@ -56,12 +56,7 @@ HONGKONG_MACAO_AND_TAIWAN 港澳台居民居住证(格式同居民身份证)
         :type NotifyType: str
         :param ApproverRole: 1--收款人、2--开具人、3--见证人
         :type ApproverRole: int
-        :param VerifyChannel: 认证方式：
-WEIXINAPP - 微信小程序；
-VERIFYCODE - 验证码；
-
-可以选择多个, 按照顺序进行优先级选择
-注：使用验证码方式认证签署时，请传入["VERIFYCODE","WEIXINAPP"]
+        :param VerifyChannel: 签署意愿确认渠道,WEIXINAPP:人脸识别
         :type VerifyChannel: list of str
         :param PreReadTime: 合同的强制预览时间：3~300s，未指定则按合同页数计算
         :type PreReadTime: int
@@ -105,6 +100,42 @@ VERIFYCODE - 验证码；
         
 
 
+class Caller(AbstractModel):
+    """此结构体 (Caller) 用于描述调用方属性。
+
+    """
+
+    def __init__(self):
+        r"""
+        :param ApplicationId: 应用号
+        :type ApplicationId: str
+        :param OrganizationId: 主机构ID
+        :type OrganizationId: str
+        :param SubOrganizationId: 下属机构ID
+        :type SubOrganizationId: str
+        :param OperatorId: 经办人的用户ID
+        :type OperatorId: str
+        """
+        self.ApplicationId = None
+        self.OrganizationId = None
+        self.SubOrganizationId = None
+        self.OperatorId = None
+
+
+    def _deserialize(self, params):
+        self.ApplicationId = params.get("ApplicationId")
+        self.OrganizationId = params.get("OrganizationId")
+        self.SubOrganizationId = params.get("SubOrganizationId")
+        self.OperatorId = params.get("OperatorId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class CancelFlowRequest(AbstractModel):
     """CancelFlow请求参数结构体
 
@@ -114,28 +145,28 @@ class CancelFlowRequest(AbstractModel):
         r"""
         :param Operator: 操作用户id
         :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
-        :param Agent: 应用相关信息
-        :type Agent: :class:`tencentcloud.ess.v20201111.models.Agent`
         :param FlowId: 流程id
         :type FlowId: str
         :param CancelMessage: 撤销原因
         :type CancelMessage: str
+        :param Agent: 应用相关信息
+        :type Agent: :class:`tencentcloud.ess.v20201111.models.Agent`
         """
         self.Operator = None
-        self.Agent = None
         self.FlowId = None
         self.CancelMessage = None
+        self.Agent = None
 
 
     def _deserialize(self, params):
         if params.get("Operator") is not None:
             self.Operator = UserInfo()
             self.Operator._deserialize(params.get("Operator"))
+        self.FlowId = params.get("FlowId")
+        self.CancelMessage = params.get("CancelMessage")
         if params.get("Agent") is not None:
             self.Agent = Agent()
             self.Agent._deserialize(params.get("Agent"))
-        self.FlowId = params.get("FlowId")
-        self.CancelMessage = params.get("CancelMessage")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -288,7 +319,7 @@ class CreateDocumentRequest(AbstractModel):
         r"""
         :param Operator: 无
         :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
-        :param TemplateId: 用户上传的模版ID
+        :param TemplateId: 用户上传的模板ID
         :type TemplateId: str
         :param FlowId: 流程ID
         :type FlowId: str
@@ -300,7 +331,8 @@ class CreateDocumentRequest(AbstractModel):
         :type Agent: :class:`tencentcloud.ess.v20201111.models.Agent`
         :param ClientToken: 客户端Token，保持接口幂等性
         :type ClientToken: str
-        :param NeedPreview: 是否需要生成预览文件 默认不生成
+        :param NeedPreview: 是否需要生成预览文件 默认不生成；
+预览链接有效期300秒；
         :type NeedPreview: bool
         """
         self.Operator = None
@@ -598,6 +630,12 @@ class CreateSchemeUrlRequest(AbstractModel):
         :type PathType: int
         :param FlowId: 合同详情 id (PathType=1时必传)
         :type FlowId: str
+        :param OrganizationName: 企业名称
+        :type OrganizationName: str
+        :param EndPoint: 链接类型 HTTP：跳转电子签小程序的http_url，APP：第三方APP或小程序跳转电子签小程序，默认为HTTP类型
+        :type EndPoint: str
+        :param AutoJumpBack: 是否自动回跳 true：是， false：否。该参数只针对"APP" 类型的签署链接有效
+        :type AutoJumpBack: bool
         """
         self.Operator = None
         self.Agent = None
@@ -605,6 +643,9 @@ class CreateSchemeUrlRequest(AbstractModel):
         self.Mobile = None
         self.PathType = None
         self.FlowId = None
+        self.OrganizationName = None
+        self.EndPoint = None
+        self.AutoJumpBack = None
 
 
     def _deserialize(self, params):
@@ -618,6 +659,9 @@ class CreateSchemeUrlRequest(AbstractModel):
         self.Mobile = params.get("Mobile")
         self.PathType = params.get("PathType")
         self.FlowId = params.get("FlowId")
+        self.OrganizationName = params.get("OrganizationName")
+        self.EndPoint = params.get("EndPoint")
+        self.AutoJumpBack = params.get("AutoJumpBack")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -951,7 +995,11 @@ class FlowCreateApprover(AbstractModel):
 
     def __init__(self):
         r"""
-        :param ApproverType: 签署方类型 (0为企业/1为个人)
+        :param ApproverType: 参与者类型：
+0：企业
+1：个人
+3：企业静默签署
+注：类型为3（企业静默签署）时，此接口会默认完成该签署方的签署。
         :type ApproverType: int
         :param OrganizationName: 如果签署方为企业，需要填入企业全称
         :type OrganizationName: str
@@ -979,6 +1027,8 @@ HONGKONG_MACAO_AND_TAIWAN 港澳台居民居住证(格式同居民身份证)
         :type PreReadTime: int
         :param NotifyType: 是否发送短信，sms--短信通知，none--不通知，默认为sms
         :type NotifyType: str
+        :param VerifyChannel: 签署意愿确认渠道,WEIXINAPP:人脸识别
+        :type VerifyChannel: list of str
         """
         self.ApproverType = None
         self.OrganizationName = None
@@ -992,6 +1042,7 @@ HONGKONG_MACAO_AND_TAIWAN 港澳台居民居住证(格式同居民身份证)
         self.IsFullText = None
         self.PreReadTime = None
         self.NotifyType = None
+        self.VerifyChannel = None
 
 
     def _deserialize(self, params):
@@ -1007,6 +1058,7 @@ HONGKONG_MACAO_AND_TAIWAN 港澳台居民居住证(格式同居民身份证)
         self.IsFullText = params.get("IsFullText")
         self.PreReadTime = params.get("PreReadTime")
         self.NotifyType = params.get("NotifyType")
+        self.VerifyChannel = params.get("VerifyChannel")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1109,6 +1161,123 @@ class StartFlowResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class UploadFile(AbstractModel):
+    """此结构体 (UploadFile) 用于描述多文件上传的文件信息。
+
+    """
+
+    def __init__(self):
+        r"""
+        :param FileBody: Base64编码后的文件内容
+        :type FileBody: str
+        :param FileName: 文件名
+        :type FileName: str
+        """
+        self.FileBody = None
+        self.FileName = None
+
+
+    def _deserialize(self, params):
+        self.FileBody = params.get("FileBody")
+        self.FileName = params.get("FileName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class UploadFilesRequest(AbstractModel):
+    """UploadFiles请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Caller: 调用方信息
+        :type Caller: :class:`tencentcloud.ess.v20201111.models.Caller`
+        :param BusinessType: 文件对应业务类型，用于区分文件存储路径：
+1. TEMPLATE - 模版； 文件类型：.pdf/.html
+2. DOCUMENT - 签署过程及签署后的合同文档 文件类型：.pdf/.html
+3. FLOW - 签署过程 文件类型：.pdf/.html
+4. SEAL - 印章； 文件类型：.jpg/.jpeg/.png
+5. BUSINESSLICENSE - 营业执照 文件类型：.jpg/.jpeg/.png
+6. IDCARD - 身份证 文件类型：.jpg/.jpeg/.png
+        :type BusinessType: str
+        :param FileInfos: 上传文件内容数组，最多支持20个文件
+        :type FileInfos: list of UploadFile
+        :param FileUrls: 上传文件链接数组，最多支持20个URL
+        :type FileUrls: str
+        :param CoverRect: 是否将pdf灰色矩阵置白
+true--是，处理置白
+false--否，不处理
+        :type CoverRect: bool
+        :param FileType: 特殊文件类型需要指定文件类型：
+HTML-- .html文件
+        :type FileType: str
+        :param CustomIds: 用户自定义ID数组，与上传文件一一对应
+        :type CustomIds: list of str
+        """
+        self.Caller = None
+        self.BusinessType = None
+        self.FileInfos = None
+        self.FileUrls = None
+        self.CoverRect = None
+        self.FileType = None
+        self.CustomIds = None
+
+
+    def _deserialize(self, params):
+        if params.get("Caller") is not None:
+            self.Caller = Caller()
+            self.Caller._deserialize(params.get("Caller"))
+        self.BusinessType = params.get("BusinessType")
+        if params.get("FileInfos") is not None:
+            self.FileInfos = []
+            for item in params.get("FileInfos"):
+                obj = UploadFile()
+                obj._deserialize(item)
+                self.FileInfos.append(obj)
+        self.FileUrls = params.get("FileUrls")
+        self.CoverRect = params.get("CoverRect")
+        self.FileType = params.get("FileType")
+        self.CustomIds = params.get("CustomIds")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class UploadFilesResponse(AbstractModel):
+    """UploadFiles返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param FileIds: 文件id数组
+        :type FileIds: list of str
+        :param TotalCount: 上传成功文件数量
+        :type TotalCount: int
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.FileIds = None
+        self.TotalCount = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.FileIds = params.get("FileIds")
+        self.TotalCount = params.get("TotalCount")
+        self.RequestId = params.get("RequestId")
+
+
 class UserInfo(AbstractModel):
     """用户信息
 
