@@ -29,6 +29,9 @@ FAILEDOPERATION_APMCONFIGINSTANCEID = 'FailedOperation.ApmConfigInstanceId'
 # 当前异步事件状态不支持此操作，请稍后重试。
 FAILEDOPERATION_ASYNCEVENTSTATUS = 'FailedOperation.AsyncEventStatus'
 
+# 登录信息验证失败，token 验证失败。
+FAILEDOPERATION_AUTHFAILURE = 'FailedOperation.AuthFailure'
+
 # 请求role信息失败。
 FAILEDOPERATION_CALLROLEFAILED = 'FailedOperation.CallRoleFailed'
 
@@ -176,6 +179,9 @@ INTERNALERROR_SYSTEMERROR = 'InternalError.SystemError'
 # FunctionName取值与规范不符，请修正后再试。可参考：https://tencentcs.com/5jXKFnBW。
 INVALIDPARAMETER_FUNCTIONNAME = 'InvalidParameter.FunctionName'
 
+# 创建函数传参异常。
+INVALIDPARAMETER_PARAMERROR = 'InvalidParameter.ParamError'
+
 # 请求参数不合法。
 INVALIDPARAMETER_PAYLOAD = 'InvalidParameter.Payload'
 
@@ -284,6 +290,12 @@ INVALIDPARAMETERVALUE_DEADLETTERCONFIG = 'InvalidParameterValue.DeadLetterConfig
 # 默认Namespace无法创建。
 INVALIDPARAMETERVALUE_DEFAULTNAMESPACE = 'InvalidParameterValue.DefaultNamespace'
 
+# DemoID  对应的函数模板 ，code 参数值有误，请确认后重试。
+INVALIDPARAMETERVALUE_DEMO = 'InvalidParameterValue.Demo'
+
+# DemoId 不存在。
+INVALIDPARAMETERVALUE_DEMOID = 'InvalidParameterValue.DemoId'
+
 # Description传入错误。
 INVALIDPARAMETERVALUE_DESCRIPTION = 'InvalidParameterValue.Description'
 
@@ -317,6 +329,12 @@ INVALIDPARAMETERVALUE_FUNCTION = 'InvalidParameterValue.Function'
 # 函数不存在。
 INVALIDPARAMETERVALUE_FUNCTIONNAME = 'InvalidParameterValue.FunctionName'
 
+# 请求 id 传参错误。
+INVALIDPARAMETERVALUE_FUNCTIONREQUESTID = 'InvalidParameterValue.FunctionRequestId'
+
+# FunctionType参数错误。
+INVALIDPARAMETERVALUE_FUNCTIONTYPE = 'InvalidParameterValue.FunctionType'
+
 # GitBranch不符合规范。
 INVALIDPARAMETERVALUE_GITBRANCH = 'InvalidParameterValue.GitBranch'
 
@@ -341,6 +359,9 @@ INVALIDPARAMETERVALUE_HANDLER = 'InvalidParameterValue.Handler'
 # IdleTimeOut参数传入错误。
 INVALIDPARAMETERVALUE_IDLETIMEOUT = 'InvalidParameterValue.IdleTimeOut'
 
+# ImageType 参数值有误。
+INVALIDPARAMETERVALUE_IMAGETYPE = 'InvalidParameterValue.ImageType'
+
 # imageUri 传入有误。
 INVALIDPARAMETERVALUE_IMAGEURI = 'InvalidParameterValue.ImageUri'
 
@@ -428,6 +449,9 @@ INVALIDPARAMETERVALUE_PUBLICNETCONFIG = 'InvalidParameterValue.PublicNetConfig'
 # 不支持的函数版本。
 INVALIDPARAMETERVALUE_QUALIFIER = 'InvalidParameterValue.Qualifier'
 
+# 查询版本详情，版本参数传入错误。
+INVALIDPARAMETERVALUE_QUERYVERSION = 'InvalidParameterValue.QueryVersion'
+
 # 企业版镜像实例ID[RegistryId]传值错误。
 INVALIDPARAMETERVALUE_REGISTRYID = 'InvalidParameterValue.RegistryId'
 
@@ -539,6 +563,9 @@ LIMITEXCEEDED_LAYERVERSIONS = 'LimitExceeded.LayerVersions'
 # layer数量超出最大限制。
 LIMITEXCEEDED_LAYERS = 'LimitExceeded.Layers'
 
+# 动态扩容最大值超限。
+LIMITEXCEEDED_MAXCAPACITY = 'LimitExceeded.MaxCapacity'
+
 # 内存超出最大限制。
 LIMITEXCEEDED_MEMORY = 'LimitExceeded.Memory'
 
